@@ -233,7 +233,9 @@ def __get_google_location(city, state, zipcode, logger):
     if response:
       if len(response) > 1:
         logger.warning(f"Google returned multiple matches for {loc_str}. Selecting a single address.")
-        selected_address = __select_address(city=city, state=state, address_list=response)
+        selected_address = None
+        if city and state:
+          selected_address = __select_address(city=city, state=state, address_list=response)
         if not selected_address:
           logger.warning(f"Cannot select a single address from multiple for {loc_str}.")
           return None
