@@ -1,5 +1,7 @@
 from dataclasses import fields
 from cc_py_commons.transactions.transaction import Transaction
+from cc_py_commons.utils.get_delivery_date import execute as get_delivery_date
+
 
 def from_load(load):
 	"""Takes a freight-hub load and maps it to a pricing load (Transaction)"""
@@ -10,7 +12,9 @@ def from_load(load):
 		
 		if value:
 			trans_data[field.name] = value
-			
+
+	if not trans_data.get('delivery_date'):
+		trans_data['delivery_date'] = get_delivery_date(pickup_date=load.pickup_date, distance_in_miles=load.distance)
 	trans_data['equipment'] = load.equipment_description
 	trans_data['all_in_cost'] = load.rate # all in cost may change at booking
 	trans_data['carrier_id'] = load.carrier_id
